<?php

/**
 * @file
 * hook_menu callback file for pm_user_image module.
 */

/**
 * Form constructor for the PM User Image Settings form.
 */
function pm_user_image_settings() {
  $form = array();
  $form['#prefix'] = "<div class='pm-user-image-desc'><strong>" . t('Image settings for the image to be shown in private message user auto complete') . '</strong></br></br>';
  $form['#suffix'] = "</div>";
  $form['pm_user_image_height'] = array(
    '#type' => 'textfield',
    '#element_validate' => array('element_validate_number'),
    '#description' => t('Specified the height of image to be shown on autocomplete Exampel :- 50'),
    '#title' => t('Image Height'),
    '#default_value' => variable_get('pm_user_image_height', 50),
  );
  $form['pm_user_image_width'] = array(
    '#type' => 'textfield',
    '#element_validate' => array('element_validate_number'),
    '#title' => t('Image Width'),
    '#description' => t('Specified the weight of image to be shown on autocomplete Exampel :- 50'),
    '#default_value' => variable_get('pm_user_image_width', 50),
  );
  $form['pm_user_image_path_type'] = array(
    '#type' => 'radios',
    '#title' => t('Image Path Type'),
    '#description' => t('User image from external source or internal image path'),
    '#options' => array(
      1 => t('External'),
      2 => t('Internal'),
    ),
    '#default_value' => variable_get('pm_user_image_path_type', 2),
  );
  $form['pm_user_image_default_image'] = array(
    '#type' => 'textfield',
    '#description' => t('Specified the path of default image for user if user has no image.</br>If image path is internal, then provide relative url like "@internal_path".</br> 
        If Image path is external then provide the full image path like @external_path', array('@internal_path' => 'sites/default/files/', '@external_path' => 'http://www.xyz.com/image')),
    '#title' => t('Default Image'),
    '#default_value' => variable_get('pm_user_image_default_image', FALSE),
  );

  return system_settings_form($form);
}

/**
 * Form validation handler for pm_user_image_settings().
 */
function pm_user_image_settings_validate(&$form, &$form_state) {
  $image_height = $form_state['values']['pm_user_image_height'];
  $image_width = $form_state['values']['pm_user_image_width'];
  $path_type = $form_state['values']['pm_user_image_path_type'];
  $default_image = $form_state['values']['pm_user_image_default_image'];
  if ($image_height < 1) {
    form_set_error('pm_user_image_height', t('Image height can not be less than 1'));
  }
  if ($image_width < 1) {
    form_set_error('pm_user_image_width', t('Image width can not be less than 1'));
  }
  if ($path_type == 1) {
    if (!valid_url($default_image, TRUE)) {
      form_set_error('pm_user_image_default_image', t('Invalid default image url'));
    }
  }
}
